


####################  Run multi-cohort analysis  #############################
# If you do not have the following packages installed, uncomment the next three lines and run them once.
# install.packages("rmeta")
# source("http://bioconductor.org/biocLite.R")
# biocLite("multtest")
library(rmeta)
library(multtest)

## Set the path where the file was unzipped
## should contain both scripts and the .RDS file
path <- "C:/exampleDirectory/sepsisFiles/"

source(file=paste0(path, "./Sepsis_MC_analysis_functions.R"))
discoveryGEMs <- readRDS(file=paste0(path, "./Sepsis_discovery_GEMs.RDS"))

## All of the nine discovery cohorts are stored in the list:
# These datasets have already been subsetted according to the criteria listed in the paper (Sweeney et al.). 
names(discoveryGEMs)

## Each item in the list has four objects:
# $expr containts processed probe-level microarray data
# $pheno contains phenotype data, in the same order (by rows) as the columns of $expr
# $keys contains the GEO-assigned probe:gene mappings for the given data set's chip type
# $class contains a binary vector with a 0 for controls (non-infected SIRS/trauma) and a 1 for cases (sepsis)

## Example phenotype file
View(discoveryGEMs$GSE28750$pheno)

## (partial) example expression file
head(discoveryGEMs$GSE28750$expr)


discoveryResults = runMetaAnalysis(discoveryGEMs)
discoveryLOOResults = leaveOneOutMetaAnalysisWrapper(discoveryGEMs)
discoveryResults$GSEnames <- names(discoveryGEMs)

## View summary statistics
View(discoveryResults$pooled.ES)

threshold = 0.01
pValHet = 0.01
thresholdStudies = length(discoveryResults$GSEnames)-1

discoveryLOOResultsFiltered <- filterLOOResults(discoveryResults, discoveryLOOResults,
                                                esThreshold = threshold, fisherThreshold = threshold, 
                                                thresholdStudies=thresholdStudies)
combined.genes <- getNonHetGenesLOO(discoveryResults, discoveryLOOResultsFiltered, pValHet=pValHet)

thresh <- ESthresh(discoveryResults, combined.genes[[1]], combined.genes[[2]], ESfold=1.5)

## 'thresh' contains the 82-gene set that survived thresholding
thresh

## "CEACAM1" is the top gene (lowest FDR) so start the search there.
forwardSearchGenes <- forwardSearchWeighted(discoveryResults, pos.genes, neg.genes, 
                                            yes.pos="CEACAM1")
## The 11-gene set
forwardSearchGenes


